#!/usr/bin/python
# -*- coding: UTF-8 -*-

from dli.exception import DliException
from pprint import pformat

from dli.types import DLITypes


class Column(object):
    data_type_list = [item.value for item in DLITypes]

    def __init__(self, name, data_type, desc=None, is_partition_column=False):
        """
        Init the Column instance

        :param str name: Column name
        :param str data_type: The data type of the column
        :param str desc: The description of the column
        :param str is_partition_column: The column whether is partition
        """

        if not Column.check_data_type(data_type):
            error_message = "Reason: data type {0} is not support.\n".format(data_type)
            raise DliException(msg=error_message)

        self._column_name = name
        self._data_type = data_type
        self._description = desc
        self._is_partition_column = is_partition_column

    @staticmethod
    def check_data_type(data_type):
        """
        Check the data_type
        :param str data_type:
        :return: boolean
        """

        if data_type.lower() in Column.data_type_list:
            return True
        else:
            for item in Column.data_type_list:
                if data_type.lower().startswith(item + "(") or data_type.lower().startswith(item + "<"):
                    return True
            return False

    @property
    def name(self):
        return self._column_name

    @property
    def type(self):
        return self._data_type.lower()

    @property
    def description(self):
        return self._description

    @property
    def is_partition_column(self):
        return self._is_partition_column

    def to_dict(self):
        column_dict = {
            'name': self.name,
            'type': self.type,
            'description': self.description,
            'is_partition_column': self.is_partition_column
        }
        return column_dict

    def to_str(self):
        return pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()
