#!/usr/bin/python
# -*- coding: UTF-8 -*-

from dli.logger import logger
from pyDLI import dli

endpoint = "dli.cn-north-7.myhuaweicloud.com"
project_id = ""
ak = ""
sk = ""
queue_name = "sql_queue"
database = "tpch"


def get_connection():
    conn = dli.Connection(host="dli://%s/%s?queuename=%s&database=%s" %
                          (endpoint, project_id, queue_name, database), ak=ak, sk=sk)
    return conn


def print_result(cursor):
    print("schema info:")
    for col_info in cursor.description:
        print("\t%s" % (col_info,))
    print("job result:")
    result_list = cursor.fetchall()
    for row_data in result_list:
        print("\t%s" % row_data)
    print(cursor.rownumber)


def exec_sql(cursor, sql, parameters=None, options=None):
    cursor.execute(sql, parameters, options)
    if (cursor._sql_job._job_type == 'DDL'):
        return
    else:
        print_result(cursor)


def exec_sql_async(cursor, sql, parameters=None, options=None):
    cursor.execute(sql, parameters, options, async_=True)
    status = cursor.poll()
    while status[0] in ('UNKNOWN', 'LAUNCHING', 'RUNNING'):
        logger.info("current job status is: %s" , status)
        status = cursor.poll()
    print_result(cursor)


def exec_sql_many(cursor, sql, seq_of_parameters):
    cursor.executemany(sql, seq_of_parameters)
    print_result(cursor)


def main():

    conn = get_connection()

    exec_sql(conn.cursor(),
             """
             CREATE TABLE IF NOT EXISTS default.all_type (
               bool_c boolean,
               t_int_c tinyint,
               s_int_c smallint,
               int_c int,
               bigint_c bigint,
               float_c float,
               double_c double,
               str_c string,
               dec_c decimal(10, 3),
               dt_c date,
               ts_c timestamp
             ) USING csv OPTIONS(path 'obs://xxx/testData/primitiveType/')
             """)
    exec_sql(conn.cursor(), "SELECT * FROM default.all_type")

    sql_conf = {'spark.sql.limit.initScanPartitionNum': '200'}

    exec_sql(conn.cursor(), "SELECT * FROM customer LIMIT 10000", options=sql_conf)
    exec_sql(conn.cursor(), "SELECT * FROM lineitem  LIMIT 10000")
    exec_sql(conn.cursor(), "SELECT * FROM nation")
    exec_sql(conn.cursor(), "SELECT * FROM nation WHERE N_REGIONKEY = %s", parameters=(2,), options=sql_conf)
    exec_sql(conn.cursor(), "SELECT * FROM orders LIMIT 10000")
    exec_sql(conn.cursor(), "SELECT * FROM part LIMIT 10000")
    exec_sql(conn.cursor(), "SELECT * FROM partsupp LIMIT 10000")
    exec_sql(conn.cursor(), "SELECT * FROM region")
    exec_sql(conn.cursor(), "SELECT * FROM supplier")

    exec_sql_async(conn.cursor(), "SELECT * FROM customer LIMIT 10000", options=sql_conf)
    exec_sql_async(conn.cursor(), "SELECT * FROM lineitem  LIMIT 10000")
    exec_sql_async(conn.cursor(), "SELECT * FROM nation")
    exec_sql_async(conn.cursor(), "SELECT * FROM nation WHERE N_NATIONKEY > %s", parameters=(10,), options=sql_conf)
    exec_sql_async(conn.cursor(), "SELECT * FROM orders LIMIT 10000")
    exec_sql_async(conn.cursor(), "SELECT * FROM part LIMIT 10000")
    exec_sql_async(conn.cursor(), "SELECT * FROM partsupp LIMIT 10000")
    exec_sql_async(conn.cursor(), "SELECT * FROM region")
    exec_sql_async(conn.cursor(), "SELECT * FROM supplier")

    exec_sql_many(conn.cursor(),
                  "SELECT * FROM nation WHERE N_NAME = %s",
                  [("ALGERIA",), ("CHINA",), ("SAUDI ARABIA",)])


if __name__ == '__main__':
    main()
